<!----------------------------------------------------------------------------->
# Manifest pipeline
<!----------------------------------------------------------------------------->

The pipeline running in the manifest repository is the one that does the real
work, like building images, generating docs and deploying image to download
servers and triggering tests in LAVA. The pipeline running in the manifest
repository is described in the `manifest-pipeline-yocto.yml` [file][1].

[1]:https://git.seco.com/edgehog/infrastructure/gitlab-ci/-/blob/master/manifest-pipeline-yocto.yml

<!----------------------------------------------------------------------------->
## Triggers
<!----------------------------------------------------------------------------->

The build in the manifest repository is currently triggered both on a weekly 
basis (on Friday evenings) on the `MASTER_BRANCH` branch and asynchronously 
whenever a merge request is opened on a project or on the repository containing
CI/CD scripts. Eventually the asynchronous build can be skipped in case the
`skip build` label is specified when opening the merge request. 

The `deploy` and `notify` stage jobs are currently triggered only on scheduled 
pipelines.

<!----------------------------------------------------------------------------->
## Build jobs
<!----------------------------------------------------------------------------->

The build stage generic description is present in the `manifest-pipeline-yocto.yml`
file while the variables which differs from board to board are imported from the 
files in the `boards` [folder][2]. To include another board within the compiled 
one it will then be necessary to include at the beginning of the 
`manifest-pipeline-yocto.yml` file the corresponding board configuration file.

The build jobs either compile the Egdehog image and the RAUC bundle for the update.

[2]:https://git.seco.com/edgehog/infrastructure/gitlab-ci/-/tree/master/boards

<!----------------------------------------------------------------------------->
## Deploy and upload jobs
<!----------------------------------------------------------------------------->

The artifacts from the previous stage are made available to the `deploy` stage 
which allows to rename, assign a tag and push to our Azure blob storage containers
all the relevant artifacts from the `build` stage, i.e. U-Boot, Kernel, `.wic`
image, etc. The upload to Azure simply takes advantage of the three [variables
defined at group level][3]:

* `AZURE_STORAGE_ACCOUNT`: the name of the blob storage account software artifacts shall be uploaded to.
* `AZURE_CONTAINER_NAME`: the name of the blob storage container used to store software artifacts.
* `AZURE_STORAGE_SAS_TOKEN`: the [SAS token][4] associated to the corresponding Azure container.

[3]:https://git.seco.com/groups/edgehog/-/settings/ci_cd
[4]:https://learn.microsoft.com/it-it/azure/cognitive-services/translator/document-translation/create-sas-tokens?tabs=Containers

<!----------------------------------------------------------------------------->
## Changelog 
<!----------------------------------------------------------------------------->

Every time a build is executed on the manifest, the changelog is also generated 
from one of the scripts accessing the GitLab API in the [scripts folder][6]. In particular, 
the job makes it possible to obtain a file in `.md` format containing the titles 
and URL references of all the MRs merged into the various meta-layers. This gives an idea of the 
various major changes between different versions of Edgehog. 

[6]:https://git.seco.com/edgehog/infrastructure/gitlab-ci/-/tree/master/scripts

<!----------------------------------------------------------------------------->
## Notify Job
<!----------------------------------------------------------------------------->

Once all jobs associated to the `build` and `deploy` stages have finished, the 
`notify` stage allows to collect the results from all previous jobs (and the link 
to the artifacts) and to send them to the dedicated channel in Microsoft Teams 
Edgehog group. The notification is allowed by using an [Incoming WebHook][5], 
saved as a [group variable][3] 

[5]:https://learn.microsoft.com/en-us/microsoftteams/platform/webhooks-and-connectors/how-to/add-incoming-webhook
<!----------------------------------------------------------------------------->
## Release 
<!----------------------------------------------------------------------------->

Only when the tag is executed will a final job also be executed that allows a [GitLab 
release][7] associated with that tag to be created. This job makes it possible 
to associate with the GitLab release all the links to the SW artifacts produced by
the build jobs in such a way that they are easily accessible, and allows the 
previously generated changelog file to be associated with the release description.

[7]:https://docs.gitlab.com/ee/user/project/releases/

![Weekly pipeline](weekly_pipeline.png)
