#!/usr/bin/env python3

from enum import Flag, auto


class ApKeys(Flag):
    """Class to specify article keys"""

    YOCTO_PKG_PY = auto()
    YOCTO_FNG_INSTALL = auto()
    YOCTO_FS = auto()
    FNGSYS_INIT = auto()
    FNGSYS_UPDATE = auto()
    FNGSYS_FS = auto()
    FNGSYS_CHECKSUM = auto()
    FNGSYS_UBOOT_UPDATE = auto()
    FNGSYS_UBOOT_IMAGE = auto()
    FNGSYS_UBOOT_CHECKSUM = auto()
    FNGSYS_UBOOT_IMAGETAR = auto()


class ApSubKeys(Flag):
    """Class to specify article subkeys"""

    MATCH = auto()
    MATCHCODE = auto()
    BEZEICHNUNG = auto()
    LANGTEXT = auto()
    TYP = auto()
    ATTRIBUTESET = auto()


def get_ap_dict(machine, machine_ap, release_name_local):
    """Return a customized dict with information for AlphaPlan FWR articles"""
    ap_dict = {}

    ap_dict[ApKeys.YOCTO_PKG_PY] = {
        ApSubKeys.MATCH: "pkg.py",
        ApSubKeys.MATCHCODE: "FNGUpdate",
        ApSubKeys.BEZEICHNUNG: "{} Flash-N-Go Update general pkg.py update"
        "script for nonverbose fng-install.sh".format(machine_ap),
        ApSubKeys.LANGTEXT: "To be used with packages the contain an "
        "fng-install.sh.\n"
        "* with --nonverbose mode (new output)\n"
        "* Able to to local installation with unset TFTP variable\n"
        "* Handle --Paramfile",
        ApSubKeys.TYP: "FNGUpdate",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.YOCTO_FNG_INSTALL] = {
        ApSubKeys.MATCH: "fng-install.sh",
        ApSubKeys.MATCHCODE: "InstallScript",
        ApSubKeys.BEZEICHNUNG: "{} {} Install Script".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "US",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.YOCTO_FS] = {
        ApSubKeys.MATCH: "{}.tar.gz".format(machine),
        ApSubKeys.MATCHCODE: "OS-Filesystem",
        ApSubKeys.BEZEICHNUNG: "{} {} Filesystem".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "FS",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_UPDATE] = {
        ApSubKeys.MATCH: "fngsystem-self-update.sh",
        ApSubKeys.MATCHCODE: "TFTP",
        ApSubKeys.BEZEICHNUNG: "{} {} Self Update".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "TFTP",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_INIT] = {
        ApSubKeys.MATCH: "fngsystem-self-init.sh",
        ApSubKeys.MATCHCODE: "InstallScript",
        ApSubKeys.BEZEICHNUNG: "{} {} Init Script".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "Updateskript",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_FS] = {
        ApSubKeys.MATCH: "{}.tgz".format(machine),
        ApSubKeys.MATCHCODE: "FS",
        ApSubKeys.BEZEICHNUNG: "{} {} Filesystem".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "FS",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_CHECKSUM] = {
        ApSubKeys.MATCH: "{}.md5".format(machine),
        ApSubKeys.MATCHCODE: "TFTP",
        ApSubKeys.BEZEICHNUNG: "{} {} Checksum".format(machine_ap, release_name_local),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "TFTP",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_UBOOT_UPDATE] = {
        ApSubKeys.MATCH: "fng-install-uboot.sh",
        ApSubKeys.MATCHCODE: "US",
        ApSubKeys.BEZEICHNUNG: "{} U-Boot {} Update script".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "Updateskript",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_UBOOT_IMAGE] = {
        ApSubKeys.MATCH: "imx-boot",
        ApSubKeys.MATCHCODE: "FS",
        ApSubKeys.BEZEICHNUNG: "{} U-Boot {} Bootloader Image".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "FS",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_UBOOT_IMAGETAR] = {
        ApSubKeys.MATCH: "imx-boot.tar.gz",
        ApSubKeys.MATCHCODE: "FS",
        ApSubKeys.BEZEICHNUNG: "{} U-Boot {} Bootloader Image".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "FS",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    ap_dict[ApKeys.FNGSYS_UBOOT_CHECKSUM] = {
        ApSubKeys.MATCH: "imx-boot.md5",
        ApSubKeys.MATCHCODE: "TFTP",
        ApSubKeys.BEZEICHNUNG: "{} U-Boot {} Checksum".format(
            machine_ap, release_name_local
        ),
        ApSubKeys.LANGTEXT: "",
        ApSubKeys.TYP: "TFTP",
        ApSubKeys.ATTRIBUTESET: "Firmware, Bestandteil eines SW-Paketes",
    }

    return ap_dict
