#!/usr/bin/env python3
import json
import os
from datetime import datetime


def generate_metadata(
    machine,
    version,
    image_artifacts,
    sdk,
    output_file,
):
    """Generate a metainfo.json for the release and write it to output_file."""

    install_script = None
    licenses = None
    image_general = None
    image_wic = None

    # Collect metadata and write to metainfo.json

    for artifact in image_artifacts:
        filename = os.path.basename(artifact)
        if filename == "fng-install.sh":
            install_script = filename
        elif filename == "license.manifest":
            licenses = filename
        elif filename.endswith(machine + ".tar.gz"):
            image_general = filename
        elif filename.endswith(machine + ".wic"):
            image_wic = filename

    metadata = dict()

    metadata["files"] = []
    metadata["version"] = version
    metadata["machine"] = machine
    metadata["date"] = datetime.today().strftime("%Y-%m-%d")

    if install_script is not None:
        new_file = dict()
        new_file["name"] = "Install Script"
        new_file["path"] = install_script
        metadata["files"].append(new_file)

    if image_general is not None:
        new_file = dict()
        new_file["name"] = "Image"
        new_file["path"] = image_general
        metadata["files"].append(new_file)

    if image_wic is not None:
        new_file = dict()
        new_file["name"] = "SD-Card Image (WIC)"
        new_file["path"] = image_wic
        metadata["files"].append(new_file)

    if sdk is not None:
        new_file = dict()
        new_file["name"] = "SDK"
        new_file["path"] = "sdk/" + sdk + ".sh"
        metadata["files"].append(new_file)

    if licenses is not None:
        new_file = dict()
        new_file["name"] = "Licenses"
        new_file["path"] = licenses
        metadata["files"].append(new_file)

    with open(output_file, "w", encoding="utf-8") as file:
        file.write(json.dumps(metadata))
