#!/usr/bin/env python3
import common

import argparse
import sys
from gitlab import Gitlab, GitlabCreateError


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--gitlab-url",
        help="""URL to the GitLab instance""",
        dest="gitlab_url",
        required=True,
    )
    parser.add_argument(
        "--token",
        help="""GitLab REST API private access token""",
        dest="token",
        required=True,
    )
    parser.add_argument(
        "--project",
        help="""name of the GitLab project""",
        dest="project",
        required=True,
    )
    parser.add_argument(
        "--ref",
        help="""branch or tag ref to trigger the pipeline for""",
        dest="ref",
        required=True,
    )

    args, _ = parser.parse_known_args()

    gitlab = Gitlab(args.gitlab_url, private_token=args.token)
    project = common.get_project(gitlab, args.project)

    try:
        pipeline = project.pipelines.create({"ref": args.ref})
    except GitlabCreateError as e:
        sys.exit("ERROR: %s" % e)

    print("Created new pipeline:")
    print(pipeline.web_url)

    sys.exit(0)


if __name__ == "__main__":
    main()
